pub struct IpV4Packet<'a> {
pub src_address: &'a [u8],
pub dst_address: &'a [u8],
pub protocol: u8,
pub payload: &'a [u8],
pub payload_off: usize,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.