pub struct NdpRouterAdvertisementField;

Implementations

Hop count to set

Managed address configuration flag

Other configuration flag

Router lifetime in seconds

The time, in milliseconds, that a node assumes a neighbor is reachable after having received a reachability confirmation

The time, in milliseconds, between retransmitted Neighbor Solicitation messages