pub struct TcpPacket<'a> {
pub src_port: &'a [u8],
pub dst_port: &'a [u8],
pub payload_off: usize,
pub payload_size: usize,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.